@@ -6,7 +6,6 @@
 
 #include "addemaildisplayjob.h"
 #include "selectaddressbookdialog.h"
-
 #include <Akonadi/AgentFilterProxyModel>
 #include <Akonadi/AgentInstanceCreateJob>
 #include <Akonadi/AgentType>
@@ -19,6 +18,7 @@
 #include <Akonadi/ContactSearchJob>
 #include <Akonadi/ItemCreateJob>
 #include <Akonadi/ItemModifyJob>
+#include <kwidgetsaddons_version.h>
 
 #include <KContacts/ContactGroup>
 #include <KLocalizedString>
@@ -155,12 +155,22 @@ public:
 
         const int nbItemCollection(canCreateItemCollections.size());
         if (nbItemCollection == 0) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (KMessageBox::questionTwoActions(
+                    mParentWidget,
+#else
             if (KMessageBox::questionYesNo(mParentWidget,
-                                           i18nc("@info", "You must create an address book before adding a contact. Do you want to create an address book?"),
-                                           i18nc("@title:window", "No Address Book Available"),
-                                           KGuiItem(i18nc("@action:button", "Create Address Book"), QStringLiteral("address-book-new")),
-                                           KStandardGuiItem::cancel())
+
+#endif
+                    i18nc("@info", "You must create an address book before adding a contact. Do you want to create an address book?"),
+                    i18nc("@title:window", "No Address Book Available"),
+                    KGuiItem(i18nc("@action:button", "Create Address Book"), QStringLiteral("address-book-new")),
+                    KStandardGuiItem::cancel())
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                == KMessageBox::ButtonCode::PrimaryAction) {
+#else
                 == KMessageBox::Yes) {
+#endif
                 QPointer<Akonadi::AgentTypeDialog> dlg = new Akonadi::AgentTypeDialog(mParentWidget);
                 dlg->setWindowTitle(i18nc("@title:window", "Add Address Book"));
                 dlg->agentFilterProxyModel()->addMimeTypeFilter(KContacts::Addressee::mimeType());
@@ -307,3 +317,4 @@ void AddEmailDisplayJob::start()
 }
 
 #include "moc_addemaildisplayjob.cpp"
+#include <kwidgetsaddons_version.h>
